@@ -32,24 +32,28 @@ struct config {
 
 	char *daemon_user;
 
-	char *username;
-	char *password;
 	char *log;
-	char *cache;
-	char *musicdir;
 	char *conf;
 	char *host;
 	char *proxy;
-	int port;
+	unsigned port;
 	int sleep;
-	int cache_interval;
+
+	/**
+	 * The interval in seconds after which the journal is saved to
+	 * the file system.
+	 */
+	unsigned journal_interval;
+
 	int verbose;
 	enum file_location loc;
+
+	GSList *scrobblers;
 };
 
 extern struct config file_config;
 
-int file_read_config(int argc, char **argv);
+int file_read_config(void);
 void file_cleanup(void);
 
 #endif /* FILE_H */
