@@ -21,7 +21,8 @@
 #ifndef LMC_H
 #define LMC_H
 
-#include <libmpdclient/libmpdclient.h>
+#include <mpd/client.h>
+
 #include <stdio.h>
 
 void lmc_connect(char *host, int port);
